@@ -14,7 +14,7 @@ Usage::
     client: IoTJobsDataPlaneClient = boto3.client("iot-jobs-data")
     session_client: IoTJobsDataPlaneClient = session.client("iot-jobs-data")
 """
-from mypy_boto3_iot_jobs_data.client import IoTJobsDataPlaneClient as Client, IoTJobsDataPlaneClient
+from mypy_boto3_iot_jobs_data.client import IoTJobsDataPlaneClient, IoTJobsDataPlaneClient as Client
 
 
 __all__ = ("Client", "IoTJobsDataPlaneClient")
